@@ -8,30 +8,18 @@ TASKS = dict([
 ])
 
 
-@configclass
-class TaskRunArguments:
-    action: str = field('train', 'specified the action name: train,eval,predict')
-
-
-@configclass
-class ExampleTasksArguments():
-    runArgs: TaskRunArguments = TaskRunArguments()
-    taskArgs = None
-
-
 def _build_arguments():
     arguments = {}
     for task_name, task_class in TASKS.items():
-        arg_obj = ExampleTasksArguments()
-        arg_obj.taskArgs = task_class.args_class()
+        arg_obj = task_class.args_class()
         arguments[task_name] = arg_obj
     return arguments
 
 
-def start_example_task(test=False, args=None):
+def start_example_task(args=None, test=False):
     argument_objs = _build_arguments()
 
-    task_name, arguments = ComplexArguments(argument_objs).parse()
+    task_name, arguments = ComplexArguments(argument_objs).parse(args)
     arguments.taskArgs.model_args.unit_test = test
     log.info("Start Example Task:{}, with arguments:{}".format(task_name, str(arguments.taskArgs)))
     task_action = arguments.runArgs.action
