@@ -1,4 +1,6 @@
+import sys
+
 from . import start_example_task
 
 if __name__ == "__main__":
-    start_example_task()
+    start_example_task(sys.argv[1:])
